@@ -9,6 +9,7 @@
 #include <QDBusConnection>
 #include <QDebug>
 
+#include <KAboutData>
 #include <KCrash>
 
 #include "abstractbrowserplugin.h"
@@ -23,6 +24,8 @@
 #include "settings.h"
 #include "tabsrunnerplugin.h"
 
+#include <version.h>
+
 void msgHandler(QtMsgType type, const QMessageLogContext &context, const QString &msg)
 {
     QJsonObject data;
@@ -84,6 +87,9 @@ int main(int argc, char *argv[])
 
     qInstallMessageHandler(msgHandler);
 
+    KAboutData about(QStringLiteral("plasma-browser-integration-host"), QString(), QStringLiteral(PBI_VERSION_STRING));
+    KAboutData::setApplicationData(about);
+
     KCrash::initialize();
 
     // NOTE if you add a new plugin here, make sure to adjust the
